@@ -1,7 +1,7 @@
 package App::cryp::Exchange::gdax;
 
-our $DATE = '2018-06-06'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $DATE = '2018-06-08'; # DATE
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use strict;
@@ -81,6 +81,11 @@ sub get_order_book {
     $apires->[2]{buy}  = delete $apires->[2]{bids};
     $apires->[2]{sell} = delete $apires->[2]{asks};
 
+    # remove the num-orders part
+    for (@{ $apires->[2]{buy} }, @{ $apires->[2]{sell} }) {
+        splice @$_, 2;
+    }
+
     [200, "OK", $apires->[2]];
 }
 
@@ -119,7 +124,7 @@ App::cryp::Exchange::gdax - Interact with Bitcoin Indonesia
 
 =head1 VERSION
 
-This document describes version 0.004 of App::cryp::Exchange::gdax (from Perl distribution App-cryp-exchange), released on 2018-06-06.
+This document describes version 0.005 of App::cryp::Exchange::gdax (from Perl distribution App-cryp-exchange), released on 2018-06-08.
 
 =for Pod::Coverage ^(.+)$
 
